/*
 * foto360.c
 *
 * Created: 2015-11-05 12:45:21
 *  Author: dsosnowski
 */ 


#define F_CPU 16000000
#include <avr/io.h>
#include <util/delay.h>
#include <avr/interrupt.h>
#include "defs.h"
#include "lcd.h"
#include "wdog.h"
#include "ee_mem.h"
#include "ui.h"
#include "stepper.h"

//--------------------------------------------------
#define MAIN_DELAY			1


//--------------------------------------------------
void HardInit(void);



struct {
	char refresh;
	char run;
	uint16_t delay;
}sys;

//--------------------------------------------------
int main(void)
{
	uint16_t startup = (1000/MAIN_DELAY);
	WdtSet(0x27);
	HardInit();
	LCDInit();
	UiInit();
	StepperInit();
	
	LCDMsg("Hello",0,0);
	UiSettingsDefault();
	 
    while(1)
    {		
		//--------------------------------------------------
		if (startup) {
			startup--;
			if (startup == 0) {
				sys.refresh = 1;
			}
		}
		
		//--------------------------------------------------
		if (UiScan()) {
			if (sys.run == STEPPER_IDLE) {
				if (UiKbdGet() == SW_OK) {
					sys.run = STEPPER_START;				
				} else {
					UiNavi();
					sys.refresh = 1;					
				}
			} else {
				if (UiKbdGet() == SW_OK) {
					//StepperIndex(1);
					//sys.run = STEPPER_RUN;
					sys.delay = 0xFFFF;
				}
					
				if (UiKbdGet() == SW_OKH) sys.run = STEPPER_STOP;
			}
		}
		
		//--------------------------------------------------
		if (sys.refresh) {
			UiMenu();
			sys.refresh = 0;
		}		
		
		//--------------------------------------------------
		if (sys.run) {
			if (sys.run == STEPPER_START) {
				StepperStart();
				sys.run = STEPPER_RUN;
			}
			if (sys.run == STEPPER_RUN) {
					sys.run = StepperNext(0);
					sys.delay = 0;
			}
			if (sys.run == STEPPER_PAUSE) {
				
				if (UiSettingsGet(MENU_MAN) == 0) {
					if (sys.delay < 0xFFFF) sys.delay++;
				}
				
				if (sys.delay >= (UiSettingsGet(MENU_DELAY) * 300)) {
					sys.delay = 0;
					BUZZ_SET;
					TRIG_SET;
					_delay_ms(20);
					BUZZ_OFF;
					_delay_ms(2000);					
					TRIG_OFF;
					_delay_ms(2000);
					StepperIndex(1);
					sys.run = STEPPER_RUN;
				} 
			}
			if (sys.run == STEPPER_STOP) {
				StepperStop();
				sys.run = STEPPER_IDLE;
			}
		}		
		
		//--------------------------------------------------
		_delay_ms(MAIN_DELAY);
		WdtReset();
    }
}

//--------------------------------------------------
void HardInit(void)
{
	
}